@@ -281,8 +281,7 @@ def compose(T, R, Z, S=None):
            [ 0.,  0.,  0.,  1.]])
     >>> S = np.zeros(3)
     >>> B = compose(T, R, Z, S)
-    >>> np.all(A == B)
-    True
+    >>> assert(np.all(A == B))  # True
 
     A null set
 
@@ -297,11 +296,9 @@ def compose(T, R, Z, S=None):
     if R.shape != (n,n):
         raise ValueError('Expecting shape (%d,%d) for rotations' % (n,n))
     A = np.eye(n+1)
+    ZS = np.diag(Z)
     if not S is None:
-        Smat = striu2mat(S)
-        ZS = np.dot(np.diag(Z), Smat)
-    else:
-        ZS = np.diag(Z)
+        ZS = ZS.dot(striu2mat(S))
     A[:n,:n] = np.dot(R, ZS)
     A[:n,n] = T[:]
     return A
