@@ -178,7 +178,7 @@ def euler2mat(ai, aj, ak, axes='sxyz'):
 
     Returns
     -------
-    mat : array-like shape (3, 3) or (4, 4)
+    mat : array (3, 3)
         Rotation matrix or affine.
 
     Examples
@@ -344,9 +344,9 @@ def euler2quat(ai, aj, ak, axes='sxyz'):
     if parity:
         aj = -aj
 
-    ai /= 2.0
-    aj /= 2.0
-    ak /= 2.0
+    ai = ai / 2.0
+    aj = aj / 2.0
+    ak = ak / 2.0
     ci = math.cos(ai)
     si = math.sin(ai)
     cj = math.cos(aj)
