@@ -259,8 +259,7 @@ def aff2sadn(aff):
     >>> angle, direction, normal, point = aff2sadn(A)
     >>> angle, direction, normal
     (0.5, array([1., 0., 0.]), array([0., 1., 0.]))
-    >>> np.all(point == [0, 0, 0])
-    True
+    >>> assert np.all(point == [0, 0, 0])
     >>> A_again = sadn2aff(angle, direction, normal, point)
     >>> np.allclose(A, A_again)
     True
