@@ -14,8 +14,8 @@ from numpy.testing import assert_array_equal, assert_array_almost_equal
 from transforms3d.testing import assert_raises
 
 
-def test_zdir_zmat_aff():
-    # test zdir to zmat and back
+def test_zfdir_zmat_aff():
+    # test zfdir to zmat and back
     for i in range(10):
         factor = np.random.random() * 10 - 5
         direct = np.random.random(3) - 0.5
@@ -153,7 +153,7 @@ def test_aff2sadn():
         # Reconstruct angle, direction, normal, point from affine
         a, d, n, p = tss.aff2sadn(S0)
         S_actual = tss.sadn2aff(a, d, n, p)
-        assert_array_almost_equal(S0, S_actual)
+        assert_array_almost_equal(S0, S_actual, decimal=5)
 
 
 def test_inverse_outer():
